<?php
// $Id: statspro_overview.inc,v 1.1.2.10 2010/06/20 11:33:22 rsevero Exp $

/**
 * @file
 *   Overview page.
 *
 */

require_once drupal_get_path('module', 'statspro') .'/statspro_settings.inc';

/**
 * Callback function for overview page.
 */
function statspro_overview($period = '', $number_of_days = NULL) {
  require_once drupal_get_path('module', 'statspro') .'/statspro.inc';

  $statspro = new statspro();

  $last_run = variable_get('statspro_last_run', 0);
  $updated = $last_run ? format_date($last_run) : t('never');

  $output = t('Last statistics update: @updated', array('@updated' => $updated));

  // add settings form
  $output .= drupal_get_form(
    'statspro_overview_settings_form',
    $period,
    $number_of_days
  );

  if ($last_run) {
    $period_info = statspro_get_period_info(
      $_SESSION['statspro_period_overview'],
      $_SESSION['statspro_custom_number_days_overview']
    );

    ////////////////////////
    // common
    $output .= theme(
      'statspro_content',
      t('General view - @period', array('@period' => $period_info['period_name'])),
      $statspro->get_stats(
        $period_info['period'],
        NULL,
        $statspro->absolute_amounts
      )
    );

    ////////////////////////
    // pi, error and warnings
    $output .= theme(
      'statspro_log',
      t('PIs, errors and warnings - @period', array('@period' => $period_info['period_name'])),
      $statspro->get_stats(
        $period_info['period'],
        $statspro->absolute_amounts
      )
    );
  }

  return $output;
}

function statspro_overview_settings_form(&$form_state, $period = '', $number_of_days = NULL) {
  set_default_session_values('_overview', $period, $number_of_days);

  return statspro_settings_form(
    $_SESSION['statspro_period_overview'],
    $_SESSION['statspro_custom_number_days_overview']
  );
}

/**
 * Implementation of hook_modulename_submit() for settings form.
 */
function statspro_overview_settings_form_submit($form, &$form_state) {
  $op = isset($form_state['values']['op']) ? $form_state['values']['op'] : '';
  if ($op == t('Reset to defaults')) {
    unset($_SESSION['statspro_period_overview']);
    unset($_SESSION['statspro_custom_number_days_overview']);
    drupal_set_message(t('The configuration options have been reset to their default values.'));
  }
  else {
    $_SESSION['statspro_period_overview'] = $form_state['values']['statspro_period'];
    if ($form_state['values']['statspro_period'] == 'custom_days') {
      $_SESSION['statspro_custom_number_days_overview'] = $form_state['values']['statspro_custom_number_days'];
    }
    drupal_set_message(t('The configuration options have been saved.'));
  }
}

function theme_statspro_content($title, $data) {
  $output = '<div id="content-area" style="margin-bottom: 30px">';

  if (is_array($data)) {
    if (statspro_get_available_chart_graphs()) {
      // get overview chart
      $output .= statspro_chart_summary($title, $data);
    }

    // theme the table
    $header = array(t('Name'), t('Value'));
    $output .= theme('table', $header, $data);
  }
  else {
    $output .= t('No content data available for specified period.');
  }

  $output .= '</div>';

  return $output;
}

function theme_statspro_log($title, $data) {
  $output = '<div id="content-area">';

  if (is_array($data)) {
    if (statspro_get_available_chart_graphs()) {
      // get overview chart
      $output .= statspro_chart_summary($title, $data);
    }

    // theme the table
    $header = array(t('Name'), t('Value'));
    $output .= theme('table', $header, $data);
  }
  else {
    $output .= t('No access and log files available for specified period.');
  }

  $output .= '</div>';

  return $output;
}

function statspro_chart_summary($title, $stats) {
  $data = array();
  $x_labels = array();

  foreach ($stats as $result) {
    $data[strip_tags($result[0])] = array($result[1]);
  }

  if (count($data) == 0) {
    return '';
  }
  else {
    require_once drupal_get_path('module', 'statspro') .'/statspro_graphs.inc';
    return statspro_get_bar_chart($title, $data, array('quantity'), TRUE);
  }
}
